==> openGion6.3.8.5_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF91S.sql <==
/****************************************************************************/
/* GF91 ( 青紙明細ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2015/09/17 15:31:10                                            */
/****************************************************************************/
CREATE TABLE GF91 (
   SYSTEM_ID    VARCHAR2 (   10 )                                       /*  10 ｼｽﾃﾑID       */
 , PGID         VARCHAR2 (   30 )                   NOT NULL            /*  20 PG-ID        */
 , TABLE_NAME   VARCHAR2 (   50 )                   NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , AS_TABLE     VARCHAR2 (    2 )                                       /*  40 ﾃｰﾌﾞﾙ別名    */
 , SEQ          NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  50 順           */
 , KBACCS       VARCHAR2 (    1 )                                       /*  60 ｱｸｾｽ区分     */
 , JOINTYPE     VARCHAR2 (    1 )                                       /*  70 連携ﾀｲﾌﾟ     */
 , BIKO         VARCHAR2 ( 2000 )                                       /*  80 備考         */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF91S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF91T00 
  BEFORE INSERT ON GF91
  FOR EACH ROW 
  BEGIN 
    SELECT GF91S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.0.3_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF91S.sql <==
/****************************************************************************/
/* GF91 ( 青紙明細ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF91 (
   SYSTEM_ID    VARCHAR2 (   10 )                                       /*  10 ｼｽﾃﾑID       */
 , PGID         VARCHAR2 (   30 )                   NOT NULL            /*  20 PG-ID        */
 , TABLE_NAME   VARCHAR2 (   50 )                   NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , AS_TABLE     VARCHAR2 (    2 )                                       /*  40 ﾃｰﾌﾞﾙ別名    */
 , SEQ          NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  50 順           */
 , KBACCS       VARCHAR2 (    1 )                                       /*  60 ｱｸｾｽ区分     */
 , JOINTYPE     VARCHAR2 (    1 )                                       /*  70 連携ﾀｲﾌﾟ     */
 , BIKO         VARCHAR2 ( 2000 )                                       /*  80 備考         */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF91S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF91T00 
  BEFORE INSERT ON GF91
  FOR EACH ROW 
  BEGIN 
    SELECT GF91S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
